@@ -1,5 +1,3 @@
-extern crate cc;
-extern crate dunce;
 use std::env;
 use std::path::Path;
 
@@ -19,16 +17,17 @@ fn main() {
             println!("cargo:warning=Don't use both lcms2 and cocoa features at the same time, see --no-default-features");
         }
         cc.define("USE_COCOA", Some("1"));
-    }
-    else if cfg!(feature = "lcms2") {
+    } else if cfg!(feature = "lcms2") {
         if let Ok(p) = env::var("DEP_LCMS2_INCLUDE") {
             cc.include(dunce::simplified(Path::new(&p)));
         }
         cc.define("USE_LCMS", Some("1"));
     }
 
-    if env::var("PROFILE").map(|p|p != "debug").unwrap_or(true) {
+    if env::var("PROFILE").map(|p| p != "debug").unwrap_or(true) {
         cc.define("NDEBUG", Some("1"));
+    } else {
+        cc.define("DEBUG", Some("1"));
     }
 
     if target_arch == "x86_64" ||
