@@ -31,6 +31,10 @@
 #define omp_get_max_threads() 1
 #endif
 
+#if PNG_LIBPNG_VER < 10400
+#error libpng version 1.4 or later is required. 1.6 is recommended. You have an obsolete version of libpng or compiling on an outdated/unsupported operating system. Please upgrade.
+#endif
+
 #if PNG_LIBPNG_VER < 10500
 typedef png_const_charp png_const_bytep;
 #endif
@@ -111,7 +115,7 @@ static void user_flush_data(png_structp png_ptr)
 }
 
 
-static png_bytepp rwpng_create_row_pointers(png_infop info_ptr, png_structp png_ptr, unsigned char *base, unsigned int height, png_size_t rowbytes)
+static png_bytepp rwpng_create_row_pointers(png_infop info_ptr, png_structp png_ptr, unsigned char *base, size_t height, png_size_t rowbytes)
 {
     if (!rowbytes) {
         rowbytes = png_get_rowbytes(png_ptr, info_ptr);
